OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
4. Plano de Ação
5. Relatório
6. Estado 0%

# Descarregue e imprima o seu relatório

Atenção! Recomendamos que tenha sempre disponível na sua empresa uma versão impressa e atualizada da sua avaliação de riscos (relatório).

Relatório

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Plano de Ação

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Visão geral dos riscos

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Visão geral das medidas

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More